@@ -18,7 +18,7 @@ class PythonSearchCli:
 
     @staticmethod
     def setup_from_config(config: PythonSearchConfiguration):
-        """Initialized the cli with the main configuration object"""
+        """Initialized the cli with the main _configuration object"""
         try:
             instance = PythonSearchCli(config)
             import fire
@@ -32,7 +32,7 @@ class PythonSearchCli:
         """Create a new project in the current directory with the given name"""
         from python_search.init_project import Project
 
-        Project().new(project_name)
+        Project().new_project(project_name)
 
     def __init__(self, configuration: PythonSearchConfiguration = None):
         """
@@ -40,7 +40,7 @@ class PythonSearchCli:
         so they keep being fast
         """
         if not configuration:
-            logging.debug("No configuration provided, using default")
+            logging.debug("No _configuration provided, using default")
             try:
                 configuration = ConfigurationLoader().load_config()
             except Exception as e:
