@@ -2,14 +2,14 @@ from __future__ import annotations
 
 import datetime
 import time
-from typing import Tuple
 
 from grimoire.event_sourcing.message import MessageBroker
 from grimoire.string import emptish
 
 from python_search.apps.clipboard import Clipboard
 from python_search.entry_capture.entry_inserter import EntryInserter
-from python_search.entry_capture.gui import EntryCaptureGUI, EntryData
+from python_search.entry_capture.entry_inserter_gui import (EntryCaptureGUI,
+                                                            EntryData)
 from python_search.exceptions import RegisterNewException
 from python_search.interpreter.base import BaseInterpreter
 from python_search.interpreter.file import FileInterpreter
@@ -54,14 +54,26 @@ class RegisterNew:
 
         self.entry_inserter.insert(entry_data.key, dict_entry)
 
-    def _infer_default_type(self, content):
-        if UrlInterpreter.is_url(content):
-            return "Url"
+    def register(self, *, key: str, value: str, tag: str = None):
+        """
+        The non ui driven registering api
+        Args:
+            key:
+            value:
+            tag:
 
-        if FileInterpreter.file_exists(content):
-            return "File"
+        Returns:
 
-        return "Cmd"
+        """
+
+        interpreter: BaseInterpreter = InterpreterMatcher.build_instance(
+            self.configuration
+        ).get_interpreter(value)
+        dict_entry = interpreter.to_dict()
+        if tag:
+            dict_entry["tags"] = [tag]
+
+        self.entry_inserter.insert(key, dict_entry)
 
     def anonymous_snippet(self):
         """
@@ -73,25 +85,27 @@ class RegisterNew:
 
         self.launch_ui(default_key=key, default_type="Snippet")
 
-    def german_from_text(self, key):
+    def german_from_text(self, german_term: str):
         """
+        @todo move this out of here to a plugin system
         Register german workds you dont know by saving them to the clipboard and storing in python search
         """
 
-        if emptish(key):
+        if len(german_term) == 0:
             raise RegisterNewException.empty_content()
 
         from python_search.interpreter.url import UrlInterpreter
 
+        print(f"german term: {german_term}")
         cmd = {
-            "url": f"https://translate.google.com/?sl=de&tl=en&text={key}&op=translate"
+            "url": f"https://translate.google.com/?sl=de&tl=en&text={german_term}&op=translate"
         }
         UrlInterpreter(cmd).interpret_default()
         time.sleep(1)
 
         from python_search.apps.collect_input import CollectInput
 
-        meaning = CollectInput().launch(f"Please type the meaning of ({key})")
+        meaning = CollectInput().launch(f"Please type the meaning of ({german_term})")
 
         if emptish(meaning):
             raise RegisterNewException.empty_content()
@@ -101,4 +115,13 @@ class RegisterNew:
             "language": "German",
         }
 
-        self.entry_inserter.insert(key, as_dict)
+        self.entry_inserter.insert(german_term, as_dict)
+
+    def _infer_default_type(self, content):
+        if UrlInterpreter.is_url(content):
+            return "Url"
+
+        if FileInterpreter.file_exists(content):
+            return "File"
+
+        return "Cmd"
